/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include "mask.xbm"
/*#include "icmask-club_mask.xbm"
#include "icmask-diamond_mask.xbm"
#include "icmask-heart_mask.xbm"
#include "icmask-spade_mask.xbm"
#define iconmask_width 16
#define iconmask_height 16*/
#include "def.h"


/* load_list_add: takes care of charging a new file 
 * as an image, and makes it a card in the list 
 * called "all" in struct _prog (see file def.h 
 * for more details about it).
 */
void load_list_add(GList **ptrlist,
	const gchar *file,
	gint num, gint family,
	GtkWidget *widget)
{
	struct _card *data_card = (struct _card*) malloc(sizeof(struct _card) );
	
	if(data_card != NULL)
	{
		data_card->family = family;
		data_card->num = num;

		data_card->dim.x = 0;
		data_card->dim.y = 0;
		
		data_card->draw = FALSE;

		data_card->img = gdk_pixmap_create_from_xpm(
			widget->window, NULL, NULL, file);
		
		gdk_drawable_get_size(data_card->img, 
			&(data_card->dim.w), &(data_card->dim.h));
		
		*ptrlist = g_list_prepend(*ptrlist, (gpointer)data_card);
	}
}

/* load_cards : l
 * this is a one time call, which takes care 
 * to load every cards (52 actually), loading 
 * the mask of them (one only) and also loads 
 * the back images of the cards (one) and 
 * icons of the different family (4)
 */
void load_cards(const gchar *path, 
	struct _prog* prog_data, GtkWidget *widget)
{
	
	GList **ptrlist = &(prog_data->all);
	
	gchar cn_ace[] = "ace";
	gchar cn_jack[] = "jack";
	gchar cn_queen[] = "queen";
	gchar cn_king[] = "king";
	gchar *c_num[13]= {cn_ace, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, cn_jack, cn_queen, cn_king};
	gchar cf_diamond[] = "diamond", cf_heart[] = "heart", cf_spade[] = "spade", cf_club[] = "club";
	gchar *c_family[4]= {cf_diamond, cf_heart, cf_spade, cf_club};

	gchar *num;
	gchar *family;
	
	gint i, j;

	/* 18 is the length of queen + diamond + "/" (ie the maximum length) */
	gchar *cardname = (gchar*)malloc(sizeof(gchar)*(strlen(path)+18));

	if(cardname != NULL)
	{
		if(prog_data->icons)
		{
			/*char *iconmask_bits = NULL;*/
			
			
			for(j=0; j < 4; j++)
			{
				family = c_family[j];
				
				sprintf(cardname, "%s/icon-%s.xpm", path, family);
				
				
				if ( g_file_test(cardname, G_FILE_TEST_EXISTS) == TRUE )
					prog_data->icons[j] = gdk_pixbuf_new_from_file(cardname, NULL);
				
				/*switch(j)
				{
					case 0:
					iconmask_bits = icmask_diamond_mask_bits;
					break;
					
					case 1:
					iconmask_bits = icmask_heart_mask_bits;
					break;
					
					case 2:
					iconmask_bits = icmask_spade_mask_bits;
					break;
					
					case 3:
					iconmask_bits = icmask_club_mask_bits;
					break;
				}
				
				*/
					
				/*	gdk_pixmap_create_from_xpm(
						widget->window,
						NULL, NULL, 
						cardname);
				*/
				
			}
		}
	

		
		
		for( i = 0; i < 13; i++)
		{
			num = c_num[i];
			
			
			for( j = 0; j < 4 ; j++)
			{
				family = c_family[j];
				
				
				if(num != NULL)
					sprintf(cardname, "%s/%s%s.xpm", path, num, family);
				else
					sprintf(cardname, "%s/%d%s.xpm", path, (i+1), family);
				
				
				if ( g_file_test(cardname, G_FILE_TEST_EXISTS) == TRUE )
				{
					load_list_add(ptrlist, cardname, i, j, widget);
				}
			}
		}
		
		if(prog_data->cardmask == NULL)
			prog_data->cardmask = gdk_bitmap_create_from_data(
				widget->window, mask_bits, mask_width, mask_height);
		
		/* back of cards */
		sprintf(cardname, "%s/back.xpm", path);
		
		if(g_file_test(cardname, G_FILE_TEST_EXISTS) == TRUE)
		{
			prog_data->back = gdk_pixmap_create_from_xpm(
				widget->window,
				&(prog_data->backmask), 
				&(prog_data->area->style->black), 
				cardname);
			
		}
		
		free(cardname);
	}
}
